@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: yesod
 version: 1.4.3
-id: yesod-1.4.3-8c82bb836d4a356b4f8138aedc5d1e45
-key: yesod_CKNJftxttR03Ah7ZXh3RO2
+id: yesod-1.4.3-a69e56397bcd6e41461537bb34d9e0ae
+key: yesod_2jJaj8YmhL1241qgioMbbg
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: Stable
@@ -21,7 +21,7 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-1.4.3
 library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-1.4.3
 data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-1.4.3
-hs-libraries: HSyesod-1.4.3-CKNJftxttR03Ah7ZXh3RO2
+hs-libraries: HSyesod-1.4.3-2jJaj8YmhL1241qgioMbbg
 depends:
     aeson-0.11.2.0-296caa0c9ed52dbc363a5964bf5cee68
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
@@ -36,7 +36,7 @@ depends:
     monad-logger-0.3.18-1374b457a8b7165408364c0bd477c532
     safe-0.3.9-b613242f536083d5bb04920ede356aea
     semigroups-0.18.1-1d5ad88275231b75d5bd2afbb0ecbbe4
-    shakespeare-2.0.8.2-ff3f7104513a25f68869f5890fce9d82
+    shakespeare-2.0.8.2-b321569ec5295e19a9b3f8b5ef85b2ad
     streaming-commons-0.1.15.5-b71913214a53247591329436a8fa2523
     template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
     text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
@@ -48,10 +48,10 @@ depends:
     wai-logger-2.2.7-be4dfe43e81d159502c14b31210da2fe
     warp-3.2.6-0273436dc44d76eb20f09024e8daa00c
     yaml-0.8.17.1-e4e3d8aa5aa8eb9fbd84f744946960bc
-    yesod-auth-1.4.13.2-70fbc297215ea529cd48a72c94deb537
-    yesod-core-1.4.20.2-aaffcf2ac447630f203677e559cbeb7c
-    yesod-form-1.4.7.1-5c01650ad8afe65749d51c18021fd186
-    yesod-persistent-1.4.0.5-144b1d8baf9d0000ea8d859d50d02dcc
+    yesod-auth-1.4.13.2-cb62b9940112dba9511200f7cb085bbb
+    yesod-core-1.4.20.2-b3dddaeebe1e00a8ca9ebbc062ef002b
+    yesod-form-1.4.7.1-73782a22913d833ae2523de889f18995
+    yesod-persistent-1.4.0.5-bf9836848c5dd8bed1442734753db9ef
 haddock-interfaces: /usr/share/doc/haskell-yesod/html/yesod.haddock
 haddock-html: /usr/share/doc/haskell-yesod/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
